@@ -1,3 +1,3 @@
 from .__version__ import __author__, __copyright__, __email__, __license__, __version__
-from ._const import ColorPoicy, ZerosRender
+from ._const import ColorPolicy, ZerosRender
 from .plugin import make_md_report, retrieve_stat_count_map
